==> bacula_2.4.2.orig.tar.gz: bacula-2.4.2/src/win32/libwin32/statusDialog.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of John Walker.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Bacula Status Dialog header file
 *
 *  Kern Sibbald, August 2007
 *
 *  Version $Id: statusDialog.h 5358 2007-08-15 16:54:21Z kerns $
 *
 */

#ifndef __STATUS_DIALOG_H_
#define __STATUS_DIALOG_H_

class statusDialog
{
public:
   statusDialog() { m_visible = false; m_textWin = NULL; };
   ~statusDialog() { };

   void display();

   void show(bool show);

   void resize(HWND win, int width, int height);

   bool m_visible;
   HWND m_textWin;
};

#endif

==> bacula_5.0.2.orig.tar.gz: bacula-5.0.2/src/win32/libwin32/statusDialog.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 * Bacula Status Dialog header file
 *
 *  Kern Sibbald, August 2007
 *
 *  Version $Id$
 *
 */

#ifndef __STATUS_DIALOG_H_
#define __STATUS_DIALOG_H_

class statusDialog
{
public:
   statusDialog() { m_visible = false; m_textWin = NULL; };
   ~statusDialog() { };

   void display();

   void show(bool show);

   void resize(HWND win, int width, int height);

   bool m_visible;
   HWND m_textWin;
};

#endif
